herosdevices.hardware.rohde_schwarz.ngx - Heros Devices 0.8.0 documentation

Skip to content
Back to top
View this page

# herosdevices.hardware.rohde_schwarz.ngx

Device driver for Rohde Schwarz NGX Power Supplies.

## Module Contents

class herosdevices.hardware.rohde_schwarz.ngx.NGX(resource: str, channels: tuple[tuple[int, str], Ellipsis] = ((1, 'ch1'),), keep_alive: bool = True, **kwargs)

  Bases: `herosdevices.core.templates.VisaDeviceTemplate`

  A channel of a RS NGX PSU with TCP/IP connection.

  channels: tuple[tuple[int, str], Ellipsis] = ((1, 'ch1'),)
  resource
  connection